Getting Started
===============

The LinchPin getting started guide will walk you through your first LinchPin project, and show off the basics of the major features LinchPin has to offer.

If you are curious about LinchPin and its features, please read the ":ref:`index-why-linchpin`" page.

This getting started guide will use LinchPin with the `dummy` provider. LinchPin can work with many other providers and use cases. After following this tutorial, check out some other :ref:`providers and use cases <providers-use-cases>`.

Before starting, please :ref:`install the latest version of LinchPin <installation>`.


.. toctree::
   :maxdepth: 1
   :hidden:

   installation
   init_workspace
   simple_workspace
   simple_pinfile
   simple_up
   hooks
   inventory
   destroy




.. seealso::

    :doc:`cli`
        Linchpin Command-Line Interface
    :doc:`workflow`
        Common LinchPin Workflows
    :doc:`managing_resources`
        Managing Resources
    :doc:`providers`
        Providers in Detail
